﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2013 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Collections.Generic;

using HeuristicLab.Common;
using HeuristicLab.Core;
using HeuristicLab.Data;
using HeuristicLab.Parameters;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;

namespace HeuristicLab.Problems.DataAnalysis.Transformations {
  [Item("CopyColumnTransformation", "Represents a transformation which represents a copied Column.")]
  public class CopyColumnTransformation<T> : Transformation<T> {
    protected const string CopiedColumnNameParameterName = "CopiedColumnName";

    #region Parameters
    public IValueParameter<StringValue> CopiedColumnNameParameter {
      get { return (IValueParameter<StringValue>)Parameters[CopiedColumnNameParameterName]; }
    }
    #endregion

    #region properties
    public string CopiedColumnName {
      get { return CopiedColumnNameParameter.Value.Value; }
    }
    #endregion

    [StorableConstructor]
    protected CopyColumnTransformation(bool deserializing) : base(deserializing) { }
    protected CopyColumnTransformation(CopyColumnTransformation<T> original, Cloner cloner)
      : base(original, cloner) {
    }
    protected CopyColumnTransformation() {
    }
    public CopyColumnTransformation(IEnumerable<string> allowedColumns)
      : base(allowedColumns) {
      Parameters.Add(new ValueParameter<StringValue>(CopiedColumnNameParameterName, "Name for the copied column", new StringValue()));
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      return new CopyColumnTransformation<T>(this, cloner);
    }

    public override IEnumerable<T> Apply(IEnumerable<T> data) {
      foreach (T a in data) {
        yield return a;
      }
    }

    public override bool Check(IEnumerable<T> data, out string errorMsg) {
      errorMsg = "";
      return true;
    }
  }
}
